Creates parallel iterator if parallel feature is enabled.
Additionally, if the object being iterated implements
IndexedParallelIterator, then one can specify a minimum size for
iteration.
Creates parallel iterator over refs if parallel feature is enabled.
Additionally, if the object being iterated implements
IndexedParallelIterator, then one can specify a minimum size for
iteration.
Creates parallel iterator over mut refs if parallel feature is enabled.
Additionally, if the object being iterated implements
IndexedParallelIterator, then one can specify a minimum size for
iteration.
Executes two closures. If parallel feature is enabled, the closures
are executed in parallel using rayon::join. Otherwise, they are
executed sequentially. The result is returned as a tuple.